clear all
set mem 700m
set matsize 800
set more off
capture log close
set logtype text
set trace off
 #delimit ; 
pause off ;
log using control_state_analysis.log, text replace;

*========================================================================================================
Program: Andrews_Stange_control_state_analysis.do
		
Created:  Sept 21, 2016 by K Stange
Updated:  Sept 21, 2016
		  Sept 26, 2016
	 
Purpose: This program compares changes in the institutions attended by Pell recipients in Texas before
and after deregulation to other states using data from FSA, OPE, IPEDS, College Scorecard, and Delta Cost.


Uses:
1. ipeds_fouryear.dta - four-year institutions from IPEDS
2. IPEDS_TX_2002 - list of Texas institutions in our analysis
3. ump_rate_0010.dta - unemployment rate by state by year
4. MERGED2011_12_PP.dta - data extracted from College Scorecard for 2011-12 (earnings by institution)
5. Barrons7208.dta - Barron's codes for institutions
6. pell_merged_1974_to_2012.dta - number of Pell recipients by institution from FSA

Creates:
1. Tables of regression outpout and figures
*========================================================================================================;	 

local PATH "";
local IPEDSPATH "";


*==============================================================================;	
* Load the IPEDS data containing all schools
*==============================================================================;

use "`IPEDSPATH'\IPEDSdata\ipeds_fouryear.dta", clear;
* Keep only public four-year institutions;
keep if sector == 1 ;


* Merge on single year of IPEDS data for Texas publics to identify schools in our sample;

mmerge unitid using "`IPEDSPATH'\IPEDSdata\IPEDS_TX_2002.dta", t(n:1) unmatched(master) ukeep(accpt_rate fgrnt_p prch_f idx_f prch_sfa idx_sfa) uname(y02_);
gen tx_sample = _merge==3;
tab year tx_sample, m;
tab instnm if tx_sample, m;

* Merge on Barrons selectivity categories;

mmerge unitid using "`IPEDSPATH'\IPEDSdata\Barrons7208.dta", t(n:1) unmatched(master) uif(year==2004 & unitid==mergeid) ukeep(barrons);
tab year _merge;
tab _merge if tx_sample==1;
list instnm unitid y02_accpt_rate y02_fgrnt_p ug_grand_total barrons if year==2004 & _merge==1 & tx_sample==1;
sort barrons;
tab barrons;
list instnm unitid y02_accpt_rate y02_fgrnt_p ug_grand_total barrons if year==2004 & _merge==3 & tx_sample==1;
tab barrons if year==2004 & tx_sample==1, sum(y02_accpt_rate) ;

* Barrons is misssing for 6 institutions. All of these look to be less or noncompetitive based on admit rate;
 *           TEXAS A & M INTERNATIONAL UNIVERSITY   226152  ;
 replace barrons = 5 if unitid==226152;
 *         THE UNIVERSITY OF TEXAS AT BROWNSVILLE   227377  ;
  replace barrons = 5 if unitid==227377;
 *                 UNIVERSITY OF HOUSTON-VICTORIA   225502  ;
  replace barrons = 5 if unitid==225502;
 *   THE UNIVERSITY OF TEXAS OF THE PERMIAN BASIN   229018  ;
  replace barrons = 5 if unitid==229018;
 *               UNIVERSITY OF HOUSTON-CLEAR LAKE   225414  ;
  replace barrons = 5 if unitid==225414;
 *               THE UNIVERSITY OF TEXAS AT TYLER   228802  ;
  replace barrons = 5 if unitid==228802;

  tab barrons tx_sample, m;
	
 gen barrons4 = .;
 replace barrons4 = 1 if barrons == 2 | barrons ==3;
  replace barrons4 = 2 if barrons == 4;
  replace barrons4 = 3 if barrons == 5;
    replace barrons4 = 4 if barrons == 6;
label def barrons4l 1 "Highly/very Comp" 2 "Competitive" 3 "Less Competitive" 4 "Noncompetitive";
label val barrons4 barrons4l;
tab barrons barrons4 if year==2004, m;
tab barrons4 tx_sample if year==2004, m;

*Merge on unemployment rate in each state X year;
* first drop a few obs with no state (these are outside the 50 states, eg. PR and GU;
list instnm  ug_grand_total if state==.;

drop if state==.;
drop if year==.;
mmerge state year using "`IPEDSPATH'\IPEDSdata\ump_rate_0010.dta", t(n:1) unmatched(master) ;

tab instnm if _merge==-1;

* Merge on earnings data from college scorecard;

local keeplist = "opeid opeid6 city stabbr zip main sch_deg main numbranch preddeg highdeg region locale locale2 latitude longitude adm_rate sat_avg  
	  mn_earn_wne_p10 md_earn_wne_p10 count_wne_p10 count_nwne_p10 pct25_earn_wne_p10 pct75_earn_wne_p10" ;
	  
mmerge unitid using "`PATH'\CollegeScorecardData\MERGED2012_13_PP.dta", t(n:1) unmatched(master) ukeep(`keeplist');

tab instnm if _merge ==1 & ug_grand_total <= 20 & ug_grand_total != . , sort ;

tab instnm if _merge ==1 & ug_grand_total > 20 & ug_grand_total != . , sort ;

gen year_fa = year;
gen year_sp = year+1;

* Merge on number of Pell Students by institution;
* This data is unique by unitid X year and (after dropping obs with missing opeid) it is unique by opeid X year
* But the Pell data is unique by opeid;
sort unitid year;

list unitid instnm year_sp ug_grand_total if opeid ==.  ;
drop if opeid == .;
* This drops ASU-East and ASU-West in 2001-2008 and ASU-Downtown in 2007-2008). These did not have an OPEID merged on from the college scorecard data;

* Need to aggregate to the opeid6 level to get proper counts of students and so that we can match the Pell counts to the correct undergrad enrollment;
* Several instittuions are disaggregated in the IPEDS data, but combined in the FSA data;

bysort opeid6 year_sp: gen tomerge = _N - 1;
tab tomerge, m;
list unitid opeid opeid6 instnm stabb year_sp ug_grand_total if tomerge != 0, sepby(stabb);

foreach var in all_full_total all_grand_total ug_full_total ug_grand_total {;
	bysort opeid6 year_sp: egen tot_`var' = total(`var');
	};
* Identify the "main" campus and then keep only that observation;
gen opeid_main = (opeid == opeid6*100);
list unitid opeid opeid6 opeid_main instnm stabb year_sp ug_grand_total tot_ug_grand_total if tomerge != 0, sepby(stabb);

list unitid opeid opeid6 instnm stabb year_sp ug_grand_total if tomerge == 0 & opeid_main == 0, sepby(stabb);

* There are two institutions that are the only campus with the opeid number in the data, but have a branch opeid number;

* 188058   2083901    20839             Northern New Mexico College       NM      2007       2252 
* This college does not appear in the IPEDS data before 2005. Looks like it switched from a 2-year to 4-year college in 2005.
* It does appear in the FSA data for all years;
* Drop it entirely;
drop if unitid == 188058;

* 187222   1039409    10394   UNIVERSITY OF MEDICINE AND DENTISTRY OF NEW JERSEY       NJ      2001        829
* This college is part of a Medical School, but does have undergraduates. The opeid number does appear in the FSA for all years. ;
* Re-code its opeid number to be the correct one;
replace opeid = 1039400 if unitid == 187222;
replace opeid_main = 1 if unitid == 187222;

* Now just keep the main campuses;
keep if opeid_main == 1;


* Check that the data is unique at a opeid6 level;
duplicates report opeid6 year_sp;

* Now merge on the FSA data;

mmerge opeid year_sp using "`PATH'\FSAPellbySchool\pell_merged_1974_to_2012.dta", t(1:1) unmatched(master) umatch(opeid year);

tab year _merge, m;

tab stabb if _merge==1;

sort stabb unitid year;
list unitid opeid opeid6 instnm stabb year_sp ug_grand_total if _merge==1, sepby(stabb);


/* ===============================================================================================================
Notes about FSA Pell data:

There are about 40 institutions that dont merge onto the FSA data in each year (341 across all 11 years). Below
I describe how we handle each case

*/
/*
1. California.  

CSU-Channel Islands (unitid 441937  opeid 3980300) - did not merge on in 2003-2005 (but did from 2006 onwards)
UC-Merced (445188   4127100) - did not merge on in 2006-2008 (but did in 2009-2012)
Drop these institutions for all years from the data
The other institutions (Hastings, UCSF have no undergrad enrollments).
*/

drop if unitid == 441937;
drop if unitid == 445188;

/*
2. Florida.

New College of Florida ( 262129   3957400 )- did not merge on 2002-2005. No record of this institution in the FSA data.
Drop this institution for all years from the data
*/

drop if unitid == 262129;
/*
3. Georgia - only nonmerged school has zero enrollment.

4. Mass -   only nonmerged school has zero enrollment (medical school).

5. Missouri -   only nonmerged school has zero enrollment (medical school).
*/

/*
6. Nevada
Nevada State College at Henderson (441900   4114300) - did not merge in 2003-2006, but did 2007 onwards
Drop this institution for all years from the data
*/

drop if unitid == 441900;
/*
7. Ohio - only nonmerged school has zero enrollment (medical school).

8. Oklahoma - only nonmerged school has zero enrollment (medical school).
*/

/*
9. South Carolina
UNIVERSITY OF SOUTH CAROLINA-BEAUFORT (218654    345000 ) - did merge in 2005, but did 2006 onwards
Drop this institution for all years from the data
*/
drop if unitid == 218654;

/*
10. Texas - only nonmerged school has zero enrollment (medical school).

11. West Virginia -  only nonmerged school has zero enrollment (medical school).
*/
/*
12. New York.  
All Pell recipients for CUNY and SUNY are reported in aggregate at the system offices in the early years:
. list name opeid year recipients if recipients > 30000 & state == "NY"

       +--------------------------------------------------------------------------------------+
       |                                                     name     opeid   year   recipi~s |
       |--------------------------------------------------------------------------------------|
14992. |                         Bank Street College Of Education    266900   2010          . |
14993. |                         Bank Street College Of Education    266900   2011          . |
14994. |                         Bank Street College Of Education    266900   2012          . |
15065. |                            City Univ Of New York-Central    268600   1999      92699 |
26224. |                    Teachers College, Columbia University    397900   2009          . |
       |--------------------------------------------------------------------------------------|
26225. |                    Teachers College, Columbia University    397900   2010          . |
26226. |                    Teachers College, Columbia University    397900   2011          . |
26227. |                    Teachers College, Columbia University    397900   2012          . |
35955. |                        Suny-State University Of New York    878800   1999      51093 |
35956. |               State University Of New York System Office    878800   2000      49641 |
       |--------------------------------------------------------------------------------------|
35957. |               State University Of New York System Office    878800   2001      49807 |
35958. |               State University Of New York System Office    878800   2002      52090 |
35959. | State University Of New York Student Loan Service Center    878800   2003      53535 |
35960. | State University Of New York Student Loan Service Center    878800   2004      53736 |
35961. | State University Of New York Student Loan Service Center    878800   2005      53450 |
       |--------------------------------------------------------------------------------------|
35962. | State University Of New York Student Loan Service Center    878800   2006      51354 |
56108. |               City University Of New York Central Office   2506100   2000      84523 |
56109. |               City University Of New York Central Office   2506100   2001      81649 |
56110. |               City University Of New York Central Office   2506100   2002      83484 |
56111. |               City University Of New York Central Office   2506100   2003      87219 |
       |--------------------------------------------------------------------------------------|
56112. |               City University Of New York Central Office   2506100   2004      91086 |
56113. |               City University Of New York Central Office   2506100   2005      94854 |
56114. |               City University Of New York Central Office   2506100   2006      93870 |


later these are broken out by branch campus, which have separate OPEID numbers. So the data for New York is basically
worthless. Just drop entire state. 

===============================================================================================================*/
drop if stabb == "NY";

drop if _merge==1;


*==============================================================================;	
* Create new variables
*==============================================================================;
destring mn_earn_wne_p10, replace force;
sum mn_earn_wne_p10;


rename recipients pell;
gen nopell = ug_grand_total - pell;

* List all the observations that have more Pell recipients than undergraduate enrollments;
list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if nopell <0, sepby(stabb);

* Something weird with U Kentucky in the first year of the data. Drop the whole state in that year;
list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if unitid ==  157085, sepby(stabb);
drop if stabb == "KY" & year_sp == 2001;

* Southern Univ at New Orleans has zero enrollment in 2006 for some reason. Just give it the average of the two spanning years;
list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if unitid ==  160630 , sepby(stabb);
replace ug_grand_total = (2824+1720)/2 if unitid == 160630 & year_sp == 2006;

* Number of Pell recipients barely exceeds total enrollment in one year. Set it equal to 100% Pell in that one year;
replace pell =  ug_grand_total if unitid == 160630 & year_sp == 2010;
replace nopell = ug_grand_total - pell if unitid == 160630;

* SANFORD-BROWN COLLEGE       MO is in the data for one year. Drop it;
list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if unitid ==  179201, sepby(stabb);
drop if unitid ==  179201;

* MISSISSIPPI VALLEY STATE UNIVERSITY has nearly a 100% Pell rate in each year. Just set it equal to 100% if it exceeds it.;
list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if unitid ==  176044, sepby(stabb);
replace pell =  ug_grand_total if unitid == 176044 & year_sp == 2004;
replace nopell = ug_grand_total - pell if unitid == 176044;

* SITTING BULL COLLEGE  has nearly a 100% Pell rate in each year. Just set it equal to 100% if it exceeds it.;

list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if unitid ==  200466 , sepby(stabb);
replace pell =  ug_grand_total if unitid == 200466 & year_sp == 2005;
replace nopell = ug_grand_total - pell if unitid == 200466;

* EASTERN NEW MEXICO UNIVERSITY-MAIN CAMPUS  has nearly a 100% Pell rate in each year. Just set it equal to 100% if it exceeds it.;

list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if unitid ==  187648 , sepby(stabb);
replace pell =  ug_grand_total if unitid == 187648 & pell > ug_grand_total;
replace nopell = ug_grand_total - pell if unitid == 187648;

* Institute of American Indian and Alaska Native Culture   has nearly a 100% Pell rate in each year. Just set it equal to 100% if it exceeds it.;
list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if unitid ==  187745  , sepby(stabb);
replace pell =  ug_grand_total if unitid == 187745  & pell > ug_grand_total;
replace nopell = ug_grand_total - pell if unitid == 187745 ;

* BLUEFIELD STATE COLLEGE seems to have an anomolous Pell volume or enrollment in 2006. Not sure which. Just set Pell to equal enrollment;
list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if unitid ==  237215 , sepby(stabb);
replace pell =  ug_grand_total if unitid == 237215 & year_sp == 2006;
replace nopell = ug_grand_total - pell if unitid == 237215;

* Drop UCSF with  no undergrad enrollments;
drop if unitid == 110699;

* Drop U North Texas Health with No undergraduates;
drop if unitid == 228909 ;

* List all the observations that have more Pell recipients than undergraduate enrollments;
list unitid opeid opeid6 instnm stabb year_sp ug_full_total ug_grand_total pell if nopell <0, sepby(stabb);
* Now there are no cases where the number of Pell students exceeds the number of undergraduate enrollments;

* Finally, there are some states that only have a single institution. For these, the pell/nonpell gap is always zero. Drop them;
drop if stabb=="DC";
drop if stabb=="WY";

gen pell_share = pell/ug_grand_total;

sum pell_share, d;
tab year_sp, sum(pell_share);

list instnm unitid year_fa year_sp ug_full_total ug_grand_total pell totaldisbursed pell_share fgrnt_p  if tx_sample==1;


preserve;

collapse (mean) meanearn_pell = mn_earn_wne_p10 (rawsum) students_pell = pell [fw = pell] , by(state stabb year_sp year_fa obereg);
save state_pell.dta, replace;

restore;

preserve;

collapse (mean) meanearn_nopell = mn_earn_wne_p10 (rawsum) students_nopell = nopell [fw = nopell] , by(state  stabb year_sp year_fa );
save state_nopell.dta, replace;

restore;

preserve;
gen ones = 1;

collapse (rawsum) num_institutions = ones (mean) meanearn_all = mn_earn_wne_p10 (rawsum) students_all = ug_grand_total [fw = ug_grand_total] , by(state stabb year_sp year_fa );
save state_all.dta, replace;

restore;

clear;
use state_pell.dta;
mmerge state year_sp using state_nopell, t(1:1);
mmerge state year_sp using state_all, t(1:1);

tab _merge;
drop _merge;

*==============================================================================;	
* Plot the number of recipients and mean earnings by state over time to spot 
* outliers
*==============================================================================;
replace students_pell = students_pell/1000;
replace students_nopell = students_nopell/1000;
replace students_all = students_all/1000;
replace meanearn_pell = meanearn_pell/1000;
replace meanearn_nopell = meanearn_nopell/1000;
replace meanearn_all = meanearn_all/1000;

gen diff_pell_nopell = meanearn_pell - meanearn_nopell;
 
gen lmeanearn_pell = log(meanearn_pell*1000);
gen lmeanearn_nopell = log(meanearn_nopell*1000);

/*
local statelist = "AK	AL	AR	AZ	CA	CO	CT	DE	FL	GA	HI	IA	ID	IL	IN	KS KY	LA	MA	MD	ME	MI	MN	MO	MS	MT	NC	ND	NE	NH	NJ	NM	NV	OH	OK	OR	PA	RI	SC	SD	TN	TX	UT	VA	VT	WA	WI	WV	";

foreach n of local statelist {;
	twoway line students_pell year_sp if stabb=="`n'", lp(dash) || 
			line students_nopell year_sp if stabb=="`n'", lp(solid) ||, 
			name(`n') title(`n') scheme(s1mono) xtitle("") ytitle("") legend(off)
			;
	};
graph combine AK	AL	AR	AZ	CA	CO	CT	DE	FL	GA	HI	IA	ID   IL	IN	KS, title("Pell and Non-Pell Enrollment") note("Dash = Pell Enrollment, Solid = NonPell Enrollment");
graph export enrollments_AK_KS.wmf, replace;
graph combine  KY LA	MA	MD	ME	MI	MN	MO	MS	MT	NC	ND	NE	NH	NJ	NM	NV, title("Pell and Non-Pell Enrollment") note("Dash = Pell Enrollment, Solid = NonPell Enrollment")	;
graph export enrollments_KY_NV.wmf, replace;
graph combine  OH  OK	OR	PA	RI	SC	SD	TN	TX	UT	VA	VT	WA	WI	WV	, title("Pell and Non-Pell Enrollment") note("Dash = Pell Enrollment, Solid = NonPell Enrollment");
graph export enrollments_OH_WY.wmf, replace;

graph drop _all;

foreach n of local statelist {;
	twoway line meanearn_pell year_sp if stabb=="`n'", lp(dash) || 
			line meanearn_nopell year_sp if stabb=="`n'", lp(solid) ||, 
			name(`n') title(`n') scheme(s1mono) xtitle("") ytitle("") legend(off)
			;
	};
graph combine AK	AL	AR	AZ	CA	CO	CT		DE	FL	GA	HI	IA	ID   IL	IN	KS, title("Pell and Non-Pell Predicted Earnings") note("Dash = Pell Earnings, Solid = NonPell Earnings");
graph export earnings_AK_KS.wmf, replace;
graph combine  KY LA	MA	MD	ME	MI	MN	MO	MS	MT	NC	ND	NE	NH	NJ	NM	NV, title("Pell and Non-Pell Predicted Earnings") note("Dash = Pell Earnings, Solid = NonPell Earnings")	;
graph export earnings_KY_NV.wmf, replace;
graph combine  OH OK	OR	PA	RI	SC	SD	TN	TX	UT	VA	VT	WA	WI	WV	, title("Pell and Non-Pell Predicted Earnings") note("Dash = Pell Earnings, Solid = NonPell Earnings");
graph export earnings_OH_WY.wmf, replace;

graph drop _all;

foreach n of local statelist {;
	twoway line diff_pell_nopell year_sp if stabb=="`n'", lp(solid) ||, 
			name(`n') title(`n') scheme(s1mono) xtitle("") ytitle("") legend(off)
			;
	};
graph combine AK	AL	AR	AZ	CA	CO	CT		DE	FL	GA	HI	IA	ID   IL	IN	KS, ycommon xcommon title("Pell - Non-Pell Predicted Earnings") ;
graph export diffearnings_AK_KS.wmf, replace;
graph combine  KY LA	MA	MD	ME	MI	MN	MO	MS	MT	NC	ND	NE	NH	NJ	NM	NV, ycommon xcommon  title("Pell and Non-Pell Predicted Earnings") 	;
graph export diffearnings_KY_NV.wmf, replace;
graph combine  OH OK	OR	PA	RI	SC	SD	TN	TX	UT	VA	VT	WA	WI	WV	, ycommon xcommon  title("Pell and Non-Pell Predicted Earnings") ;
graph export diffearnings_OH_WY.wmf, replace;

graph drop _all;

*/

*==============================================================================;	
* Create new variables
*==============================================================================;
 gen post = (year_fa >= 2004);

 gen texas = state==48;
 
 gen post_texas = post*texas;
 

 * All states, only Texas dummy;
 regress meanearn_pell texas post post_texas, cluster(state);
 outreg2 using control_state_analysis.xls, excel replace addtext(sample, All, FE, none, Weights, none) ;
 
 regress meanearn_nopell texas post post_texas, cluster(state);
 outreg2 using control_state_analysis.xls, excel append addtext(sample, All, FE, none, Weights, none);
 
 regress diff_pell_nopell post if texas==1, robust;
  outreg2 using control_state_analysis.xls, excel append addtext(sample, TX only, FE, none, Weights, none);
   
 regress diff_pell_nopell texas post post_texas, cluster(state);
  outreg2 using control_state_analysis.xls, excel append addtext(sample, All, FE, none, Weights, none);
 
 
 * All states, state FE;
  areg diff_pell_nopell post_texas i.year_fa , absorb(state) cluster(state) ;
  outreg2 using control_state_analysis.xls, excel append addtext(sample, All, FE, state, Weights, none);
	
  areg diff_pell_nopell post_texas i.year_fa [aw = students_all], absorb(state) cluster(state) ;
  outreg2 using control_state_analysis.xls, excel append addtext(sample, All, FE, state, Weights, enrollment);
   
 * All SE states;
 areg diff_pell_nopell post_texas i.year_fa if (texas==1 | obereg==5) , absorb(state) cluster(state) ;
   outreg2 using control_state_analysis.xls, excel append addtext(sample, SE, FE, state, Weights, none);
   
 areg diff_pell_nopell post_texas i.year_fa if (texas==1 | obereg==5) [aw = students_all], absorb(state) cluster(state) ;
   outreg2 using control_state_analysis.xls, excel append addtext(sample, SE, FE, state, Weights, enrollment);
   
 * All SE states excluding FL;
 areg diff_pell_nopell post_texas i.year_fa if ((texas==1 | obereg==5)&(state!= 12)) , absorb(state) cluster(state) ;
    outreg2 using control_state_analysis.xls, excel append addtext(sample, SE no FL, FE, state, Weights, none);
	
 areg diff_pell_nopell post_texas i.year_fa if ((texas==1 | obereg==5)&(state!= 12)) [aw = students_all], absorb(state) cluster(state) ;
     outreg2 using control_state_analysis.xls, excel append addtext(sample, SE no FL, FE, state, Weights, enrollment);

	  * All SE and SW states excluding FL;
 areg diff_pell_nopell post_texas i.year_fa if ((texas==1 | obereg==5 | obereg ==6)&(state!= 12)) , absorb(state) cluster(state) ;
    outreg2 using control_state_analysis.xls, excel append addtext(sample, SESW no FL, FE, state, Weights, none);
	
 areg diff_pell_nopell post_texas i.year_fa if ((texas==1 | obereg==5 | obereg ==6)&(state!= 12)) [aw = students_all], absorb(state) cluster(state) ;
     outreg2 using control_state_analysis.xls, excel append addtext(sample, SESW no FL, FE, state, Weights, enrollment);


* Synthetic control groups;
* KY was dropped for the first year because of weird Pell data. Drop the rest of the years from synth control
* analysis so that we have a balanced panel;
# delimit ;

drop if stabb == "KY" ;

tsset state year_fa;

gen pell_share = students_pell/students_all;
gen insts_per_enroll = num_institutions/students_all;

preserve;
label var diff_pell_nopell "Pell-NonPell Mean Earnings Gap ($1,000)";
*synth diff_pell_nopell diff_pell_nopell , trunit(48) trperiod(2004) figure unitnames(stabb) keep(synth48.dta) replace;
*synth diff_pell_nopell pell_share insts_per_enroll meanearn_all  , trunit(48) trperiod(2004) figure unitnames(stabb) keep(synth48.dta) replace;
synth diff_pell_nopell diff_pell_nopell pell_share insts_per_enroll meanearn_all  , trunit(48) trperiod(2004) figure unitnames(stabb) keep(synth48.dta) replace;

graph export synth_control.wmf, replace; 

use synth48.dta, clear;
rename _Y_treated diff_pell_nopell1 ;
rename _Y_synthetic diff_pell_nopell0 ;
keep if _time != .;
rename _time year_fa;
drop _Co_Number _W_Weight;

reshape long diff_pell_nopell, i(year_fa) j(texas);
label val texas;
gen post = (year_fa >= 2004);
gen post_texas = post*texas;

 reg diff_pell_nopell post_texas i.year_fa texas , robust ;
 outreg2 using control_state_analysis.xls, excel append addtext(sample, synth controls, FE, none, Weights, none);
 
 
 
restore;	 

local statenum1 = "48 1	2	4	5	6	8	9	10	12	13	15	16	17	18	19	20	22	23	24	25	26	27	28	29	30	31	32	33	34	35	37	38	39	40	41	42	44	45	46	47	49	50	51	53	54	55	";
local rmspe_threshold = 5;

foreach n of local statenum1 {; 
synth diff_pell_nopell diff_pell_nopell pell_share insts_per_enroll meanearn_all , trunit(`n') trperiod(2004) figure unitnames(stabb) keep(synth`n'.dta) replace;
matrix R = e(RMSPE);

if `n' == 48 {;
	local  rmspe48 = R[1,1] ;
	};
local rmspe = R[1,1];

preserve;
use synth`n'.dta, clear;
keep if _time != .;
gen d`n' = _Y_treated - _Y_synth ;
rename _time time;
keep time d`n';
* Set difference variable to missing if RMSPE is X times the RMSPE for Texas;
if `rmspe' > `rmspe_threshold'*`rmspe48' {;
	replace d`n' = .;
	};
	
save synth`n'.dta, replace;
restore;
};

preserve;
local statenum2 = "1	2	4	5	6	8	9	10	12	13	15	16	17	18	19	20	22	23	24	25	26	27	28	29	30	31	32	33	34	35	37	38	39	40	41	42	44	45	46	47	49	50	51	53	54	55	";
use synth48.dta, clear;

foreach n of local statenum2 {; 
mmerge time using synth`n'.dta, t(1:1);
erase synth`n'.dta;
};

twoway 
line d1	d2	d4	d5	d6	d8	d9		d10	d12		time, lc( gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12) lw( thin thin thin thin thin thin thin thin thin) ||
line d13 d15	d16	d17	d18	d19	d20	d22	d23	d24		time, lc(gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12) lw(thin thin thin thin thin thin thin thin thin thin) ||
line d25 d26	d27	d28	d29	d30	d31	d32	d33	d34		time, lc(gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12) lw(thin thin thin thin thin thin thin thin thin thin) || 
line d35 d37	d38	d39	d40	d41	d42	d44	d45	d46	 time, lc(gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12 gs12) lw(thin thin thin thin thin thin thin thin thin thin) ||
line d47 d49	d50	d51	d53	d54	d55	 time,             lc( gs12 gs12 gs12 gs12 gs12 gs12 gs12 )          lw( thin thin thin thin thin thin thin)           ||
line d48 time, lc(black) lw(medthick) || , 
xline(2003.5) yline(0, lc(black)) ytitle("Change in Pell-NonPell Mean Earnings Gap" "vs. Synthetic Control ($1,000)") 
legend(order(49 1) region(ls(none)) label(49 "Texas") label(1 "Placebo states"));

graph export synth_control_placebo.wmf, replace;

 
restore;





*==============================================================================;	
* end of program
*==============================================================================;


	log close;
	